@@ -1,4 +1,4 @@
-use nxui::chooser::*;
+use nxui::file_chooser::*;
 use nxui::messagebox::MessageBox;
 use nxui::natives_and_messaging::*;
 use nxui::window::Frame;
