@@ -1,5 +1,4 @@
-use nxui::io::storage::Storage;
-use nxui::natives_and_messaging::{ADVANCED_WINDOWSTYLE_UTILITY, WINDOWSTYLE_NORMAL};
+use nxui::natives_and_messaging::{AWS_UTILITY, WS_NORMAL};
 use nxui::window::{AdvancedOptions, Application, Frame, Attributes};
 
 fn main() {
@@ -26,7 +25,7 @@ impl Application for UtilityApplication {
     }
 
     fn attributes(&self) -> Attributes {
-        Attributes::new(WINDOWSTYLE_NORMAL, "Utility Window".to_string(),400, 675, 100, 100)
+        Attributes::new(WS_NORMAL, "Utility Window".to_string(),400, 675, 100, 100)
     }
 
     fn is_child_window(&self) -> bool {
@@ -34,7 +33,7 @@ impl Application for UtilityApplication {
     }
 
     fn advanced_options(&self) -> AdvancedOptions {
-        AdvancedOptions::new(ADVANCED_WINDOWSTYLE_UTILITY)
+        AdvancedOptions::new(AWS_UTILITY)
     }
 
     fn ui(&self, frame: Frame) {
