@@ -20,7 +20,7 @@ impl Application for DemoWindow {
     }
 
     fn attributes(&self) -> Attributes {
-        Attributes::new(WINDOWSTYLE_NORMAL, "NXUI Window".to_string(),1280, 750, 100, 100)
+        Attributes::new(WS_NORMAL, "NXUI Window".to_string(),1280, 750, 100, 100)
     }
 
     fn is_child_window(&self) -> bool {
