@@ -8,7 +8,8 @@ pub mod io;
 pub mod util;
 pub mod widget;
 pub mod demo;
-pub mod chooser;
+pub mod file_chooser;
+pub mod directory_chooser;
 
 #[macro_use]
 extern crate log;
