@@ -2,6 +2,9 @@
 //! What starts with DIALOGSTYLE is Constants that set the dialog icon information.
 //! What starts with BUTTONSTYLE is a constant for changing the buttons in the dialog.
 
+
+pub type FILE_CHOOSER_STYLE = i32;
+
 // Dialog Styles
 
 
@@ -263,8 +266,16 @@ pub const AWS_UTILITY: windows_sys::Win32::UI::WindowsAndMessaging::WINDOW_EX_ST
 pub const AWS_UTILITY: gtk::gdk::WindowTypeHint = gtk::gdk::WindowTypeHint::Utility;
 
 /// File Chooser Attributes
+#[cfg(windows)]
 pub const FC_NONE:winapi::shared::minwindef::DWORD = 0;
+#[cfg(unix)]
+pub const FC_NONE:FILE_CHOOSER_STYLE = 0;
+#[cfg(windows)]
 pub const FC_DISABLE_READ_ONLY:winapi::shared::minwindef::DWORD = winapi::um::commdlg::OFN_HIDEREADONLY;
+#[cfg(unix)]
+pub const FC_DISABLE_READ_ONLY:FILE_CHOOSER_STYLE = 0;
 /// Windows Only
+#[cfg(windows)]
 pub const FC_NEW_EXPLORER:winapi::shared::minwindef::DWORD = winapi::um::commdlg::OFN_EXPLORER;
+#[cfg(windows)]
 pub const FC_ENABLE_HELP:winapi::shared::minwindef::DWORD = winapi::um::commdlg::OFN_SHOWHELP;
