@@ -51,7 +51,7 @@ pub fn create_new_app(application: Box<dyn Application>) {
         let atom = RegisterClassA(&wc);
         debug_assert!(atom != 0);
 
-        let win = CreateWindowExA(application.advanced_options().get_style(), "window".as_ptr(), attributes.title.as_ptr(), attributes.style|WS_VISIBLE, attributes.x, attributes.y, attributes.width, attributes.height, 0, 0, instance, std::ptr::null_mut());
+        let win = CreateWindowExA(application.advanced_options().get_style(), "window".as_ptr(), format!("{}\0",attributes.title).as_ptr(), attributes.style|WS_VISIBLE, attributes.x, attributes.y, attributes.width, attributes.height, 0, 0, instance, std::ptr::null_mut());
         info!("A window has been created. handle: {}",win);
 
         let frame = Frame::new(win);
